@@ -1,10 +1,11 @@
-{-# LANGUAGE DataKinds #-}
+{-# LANGUAGE DataKinds          #-}
 {-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE KindSignatures #-}
-{-# LANGUAGE PolyKinds #-}
+{-# LANGUAGE KindSignatures     #-}
+{-# LANGUAGE PolyKinds          #-}
 module Servant.API.Experimental.Auth where
 
-import           Data.Typeable (Typeable)
+import           Data.Typeable
+                 (Typeable)
 
 -- | A generalized Authentication combinator. Use this if you have a
 -- non-standard authentication technique.
